@@ -9,10 +9,10 @@ import os
 
 def get_ecses():
     cfg = ado_ini.read_cfg()
-    print('regions:',cfg.get('default', 'regionids').split(','))
-    cli = ali_cli.AliCli(cfg.get('default', 'accesskeyid'),
-                         cfg.get('default', 'accesskeysecret'),
-                         cfg.get('default', 'regionids').split(','))
+    print('regions:',cfg.get('config', 'regionids').split(','))
+    cli = ali_cli.AliCli(cfg.get('config', 'accesskeyid'),
+                         cfg.get('config', 'accesskeysecret'),
+                         cfg.get('config', 'regionids').split(','))
     return [ecs for ecs in cli.ecses_iterator()]
 
 
