@@ -13,9 +13,9 @@ if not os.path.exists(ini_file):
     cfg = ConfigParser.RawConfigParser()
     cfg.add_section('config')
     # cfg.set('config','accesskeyid','')
-    cfg.set('config','accesskeyid',input('请输入accesskeyid:'))
-    cfg.set('config','accesskeysecret',input('accesskeysecret:'))
-    cfg.set('config','regionids',input('请输入regionids(","分隔):'))
+    cfg.set('config','accesskeyid',raw_input('请输入accesskeyid:'))
+    cfg.set('config','accesskeysecret',raw_input('accesskeysecret:'))
+    cfg.set('config','regionids',raw_input('请输入regionids(","分隔):'))
     print('需要在配置文件中设置相应值,配置文件：',ini_file)
     with open (ini_file,'+w') as f:
         cfg.write(f)
